Source-Changes-HG archive

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]

[src/trunk]: src/lib/libpthread Follow-up to previous. In pthread__signal_tr...



details:   https://anonhg.NetBSD.org/src/rev/21a76ee4a408
branches:  trunk
changeset: 555547:21a76ee4a408
user:      uwe <uwe%NetBSD.org@localhost>
date:      Thu Nov 20 17:45:00 2003 +0000

description:
Follow-up to previous.  In pthread__signal_tramp() maskp is below
siginfo on the stack, so get it from there.  ss_sp no longer points to
the the mask.  Pointed out by cl@.

diffstat:

 lib/libpthread/pthread_sig.c |  8 ++++----
 1 files changed, 4 insertions(+), 4 deletions(-)

diffs (30 lines):

diff -r feb70ab1bb84 -r 21a76ee4a408 lib/libpthread/pthread_sig.c
--- a/lib/libpthread/pthread_sig.c      Thu Nov 20 17:38:08 2003 +0000
+++ b/lib/libpthread/pthread_sig.c      Thu Nov 20 17:45:00 2003 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: pthread_sig.c,v 1.26 2003/11/20 17:16:41 uwe Exp $     */
+/*     $NetBSD: pthread_sig.c,v 1.27 2003/11/20 17:45:00 uwe Exp $     */
 
 /*-
  * Copyright (c) 2001 The NetBSD Foundation, Inc.
@@ -37,7 +37,7 @@
  */
 
 #include <sys/cdefs.h>
-__RCSID("$NetBSD: pthread_sig.c,v 1.26 2003/11/20 17:16:41 uwe Exp $");
+__RCSID("$NetBSD: pthread_sig.c,v 1.27 2003/11/20 17:45:00 uwe Exp $");
 
 /* We're interposing a specific version of the signal interface. */
 #define        __LIBC12_SOURCE__
@@ -929,9 +929,9 @@
                struct pthread__sigcontext psc;
                /*
                 * XXX we don't support siginfo here yet.
                 * Note that uc_stack.ss_sp holds the old sigmask
                 */
-               sigset_t *maskp = uc->uc_stack.ss_sp;
+               sigset_t *maskp = (sigset_t *)(void *)&info[1];
                PTHREAD_UCONTEXT_TO_SIGCONTEXT(maskp, uc, &psc);
                ((void *(*)(int, int, struct sigcontext *))handler)
                    (info->si_signo, info->si_trap, &psc.psc_context);
@@ -929,9 +929,9 @@
                /*
                 * XXX we don't support siginfo here yet.
-                * Note that uc_stack.ss_sp holds the old sigmask
+                * Note that the old sigmask is below info in the stack.
                 */



Home | Main Index | Thread Index | Old Index